/* Directory hotlist -- for the Midnight Commander
 * Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
 * 2003, 2004, 2005, 2006, 2007,2008  Free Software Foundation, Inc.
 * 
 * 
 * See OrigAuthors.txt in top directory of module
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  
 */
/* ************************************************************************** */
#define USE_MC_MODULE__HOTLIST_PRIVATE_H 1
/* -------------------------------------------------------------------------- */
#include <config.h>

#include "global.h"
#include "tty.h"		/* COLS */
#include "color.h"		/* dialog_colors */
#include "dialog.h"
#include "widget.h"

#include "hotlist/private.h"
#include "hotlist/library.h"
#include "hotlist/view/view_main_window.h"
/* -------------------------------------------------------------------------- */
#include "hotlist/public.h"

#define LABELS          3
#define B_ADD_CURRENT	B_USER
#define B_REMOVE        (B_USER + 1)
#define B_NEW_GROUP	(B_USER + 2)
#define B_NEW_ENTRY	(B_USER + 3)
#define B_UP_GROUP	(B_USER + 4)
#define B_INSERT	(B_USER + 5)
#define B_APPEND	(B_USER + 6)
#define B_MOVE		(B_USER + 7)
#define B_EDIT		(B_USER + 8)

#ifdef USE_VFS
#include "../vfs/gc.h"
#define B_FREE_ALL_VFS	(B_USER + 8)
#define B_REFRESH_VFS	(B_USER + 9)
#endif

//#define BX		UX
//#define BY		(LINES - 6)

//#define UX		5
//#define UY		2

typedef struct s_hotlist_v_main_window_button {
    int ret_cmd, flags, y, x;
    const char *text;
    int   type;
} ts_hotlist_v_main_window_button;


/* ************************************************************************** */
enum {
    HL_BEFORE_CURRENT = 1
   ,HL_AFTER_CURRENT  = 2
};

/* ************************************************************************** */
ts_hotlist_v_main_window *hotlist_v_main_window_init(ts_hotlist *_hotlist){
    size_t i;
    Dlg_head *hotlist_dlg;
    const char *title, *help_node;

    int hotlist_cols;

    ts_hotlist_v_main_window *ret_dlg;

    ret_dlg = g_malloc(sizeof(ts_hotlist_v_main_window));
    if (ret_dlg == NULL) {
	return NULL;
    }
    hotlist_v_main_window_init_title_helpnode(ret_dlg, _hotlist);
    if (hotlist_v_main_window_init_buttons(ret_dlg) == FALSE){
	g_free(ret_dlg);
	return NULL;
    }
//    hotlist_v_main_window_init_list(ret_dlg,_hotlist);
    // FIXME: init_i18n_stuff MUST be outsize of this module!..
    hotlist_cols = init_i18n_stuff (_hotlist->state.type, COLS - 6);

    hotlist_dlg =
	create_dlg (0, 0, LINES - 2, hotlist_cols, dialog_colors,
		hotlist_v_main_window_callback, help_node, title, DLG_CENTER | DLG_REVERSE);

/*    
        for (i = 0; i < BUTTONS; i++) {
	if (hotlist_but[i].type & _hotlist->state.type)
	    add_widget (hotlist_dlg,
			button_new (BY + hotlist_but[i].y,
				    BX + hotlist_but[i].x,
				    hotlist_but[i].ret_cmd,
				    hotlist_but[i].flags,
				    hotlist_but[i].text,
				    *//*hotlist_button_callback*//* NULL));
    }
*/

}
/* -------------------------------------------------------------------------- */
void hotlist_v_main_window_init_title_helpnode(ts_hotlist_v_main_window *_dlg, ts_hotlist *_hotlist){
    if (_hotlist->state.type == LIST_VFSLIST) {
	_dlg->title = _("Active VFS directories");
	_dlg->help_node = "[vfshot]";
    } else {
	_dlg->title = _("Directory hotlist");
	_dlg->help_node = "[Hotlist]";
    }
}
/* -------------------------------------------------------------------------- */
int hotlist_v_main_window_init_buttons(ts_hotlist_v_main_window *_dlg){
    
#if 0
     hotlist_but[] = {
    /* two rows of hotlist buttons */
    /* bottom row */
    { B_NEW_GROUP, NORMAL_BUTTON,	1,	45,	N_("New group <F7>"),	LIST_HOTLIST},
    { B_MOVE, NORMAL_BUTTON,		1,	30,	N_("Move <F6>"),	LIST_HOTLIST},
    { B_REMOVE, NORMAL_BUTTON,		1,	 0,	N_("Delete <Del>"),	LIST_HOTLIST},
    /* top row */
    { B_CANCEL, NORMAL_BUTTON,		0,	53,	N_("Cancel"),		LIST_HOTLIST|LIST_VFSLIST|LIST_MOVELIST},
    { B_NEW_ENTRY, NORMAL_BUTTON,	0,	30,	N_("New entry <Ins>"),	LIST_HOTLIST},
    { B_EDIT, NORMAL_BUTTON,		0,	16,	N_("Edit <F4>"),	LIST_HOTLIST},
    { B_ENTER, DEFPUSH_BUTTON,		0,	 0,	N_("Go to"),		LIST_HOTLIST|LIST_VFSLIST},
    /* movelist buttons */
    { B_INSERT, NORMAL_BUTTON,		0,	15,	N_("Insert before"),	LIST_MOVELIST},
    { B_APPEND, DEFPUSH_BUTTON,		0,	0,	N_("Insert after"),	LIST_MOVELIST},
#ifdef	USE_VFS
    { B_REFRESH_VFS, NORMAL_BUTTON,	0,	43,	N_("&Refresh"),		LIST_VFSLIST},
    { B_FREE_ALL_VFS, NORMAL_BUTTON,	0,	20,	N_("Fr&ee VFSs now"),	LIST_VFSLIST},
#endif
    { NULL, NULL,	0,	0,	NULL,	NULL},
    };
#endif
}
/* -------------------------------------------------------------------------- */
